@@ -9,6 +9,9 @@
 #include <QFuture>
 #include <QFutureWatcher>
 
+#include <QCoroTask>
+#include <QCoroFuture>
+
 #include <iostream>
 #include <vector>
 
@@ -50,53 +53,6 @@ private:
     std::unique_ptr<T> m_item = nullptr;
 };
 
-///
-/// Similar to QObject::connect, except that the first two arguments are replaced with a QFuture.
-///
-template <typename T, typename QObjectDerivedType, typename Function>
-void connectFuture(const QFuture<T> &future, QObjectDerivedType *self, const Function &fun) {
-    auto watcher = std::make_shared<QFutureWatcher<T>>();
-    watcher->setFuture(future);
-    QObject::connect(watcher.get(), &QFutureWatcherBase::finished, self, [self, watcher, fun, future]() {
-        if constexpr (std::is_same_v<void, T>) {
-            if constexpr (std::is_member_function_pointer_v<Function>) {
-                (self->*fun)();
-            } else {
-                Q_UNUSED(self);
-                fun();
-            }
-        } else if (future.resultCount() > 0) {
-            if constexpr (std::is_member_function_pointer_v<Function>) {
-                (self->*fun)(watcher->result());
-            } else {
-                Q_UNUSED(self);
-                fun(watcher->result());
-            }
-        }
-    });
-}
-
-///
-/// Applies a function to a the contained value of a QFuture once it finishes.
-/// @returns a QFuture that finishes once the future given as first argument finished
-///
-template <typename T, typename Func>
-QFuture<std::invoke_result_t<Func, T>> mapFuture(const QFuture<T> &future, Func mapFunction) {
-    using ReturnType = std::invoke_result_t<Func, T>;
-    auto watcher = std::make_shared<QFutureWatcher<T>>();
-    watcher->setFuture(future);
-
-    auto interface = std::make_shared<QFutureInterface<ReturnType>>();
-    QObject::connect(watcher.get(), &QFutureWatcherBase::finished, watcher.get(), [interface, watcher, mapFunction] {
-        auto result = watcher->result();
-        auto mapped = mapFunction(std::move(result));
-        interface->reportResult(mapped);
-        interface->reportFinished();
-    });
-
-    return interface->future();
-}
-
 class AsyncYTMusic : public QObject
 {
     friend class YTMusicThread;
