@@ -22,8 +22,6 @@ void pyPrintPretty(py::handle obj) {
 
 #define UNEXPORT __attribute__ ((visibility("hidden")))
 
-constexpr auto TESTED_YTMUSICAPI_VERSION = "0.25.0";
-
 struct UNEXPORT YTMusicPrivate {
     py::scoped_interpreter guard {};
 
@@ -135,7 +133,7 @@ inline auto extract_py_list(py::handle obj) {
 
 album::Track extract_album_track(py::handle track) {
     return {
-        track["isExplicit"].cast<bool>(),
+        optional_key<bool>(track, "isExplicit"),
         track["title"].cast<std::string>(),
         extract_py_list<meta::Artist>(track["artists"]),
         track["album"].cast<std::optional<std::string>>(),
@@ -150,7 +148,7 @@ video_info::Format extract_format(py::handle format) {
         optional_key<float>(format, "quality"),
         format["url"].cast<std::string>(),
         format["vcodec"].cast<std::string>(),
-        format["acodec"].cast<std::string>()
+        optional_key<std::string>(format, "acodec").value_or("none") // returned inconsistently by yt-dlp
     };
 }
 
@@ -197,11 +195,11 @@ playlist::Track extract_playlist_track(py::handle track) {
 
             return extract_meta_album(track["album"]);
         }(),
-        track["duration"].cast<std::string>(),
+        optional_key<std::string>(track, "duration"),
         track["likeStatus"].cast<std::optional<std::string>>(),
         extract_py_list<meta::Thumbnail>(track["thumbnails"]),
         track["isAvailable"].cast<bool>(),
-        track["isExplicit"].cast<bool>()
+        optional_key<bool>(track, "isExplicit")
     };
 }
 
@@ -277,6 +275,17 @@ std::optional<artist::Artist::Section<T>> extract_artist_section(py::handle arti
 std::optional<search::SearchResultItem> extract_search_result(py::handle result) {
     const auto resultType = result["resultType"].cast<std::string>();
 
+    if (result["category"].cast<std::optional<std::string>>() == "Top result") {
+        return search::TopResult {
+            result["category"].cast<std::string>(),
+            result["resultType"].cast<std::string>(),
+            optional_key<std::string>(result, "videoId"),
+            optional_key<std::string>(result, "title"),
+            extract_py_list<meta::Artist>(result["artists"]),
+            extract_py_list<meta::Thumbnail>(result["thumbnails"])
+        };
+    }
+
     if (resultType == "video") {
         return search::Video {
             {
@@ -298,7 +307,7 @@ std::optional<search::SearchResultItem> extract_search_result(py::handle result)
                 extract_py_list<meta::Thumbnail>(result["thumbnails"])
             },
             result["album"].is_none() ? std::optional<meta::Album> {} : extract_meta_album(result["album"]),
-            result["isExplicit"].cast<bool>()
+            optional_key<bool>(result, "isExplicit")
         };
     } else if (resultType == "album") {
         return search::Album {
@@ -314,7 +323,7 @@ std::optional<search::SearchResultItem> extract_search_result(py::handle result)
         return search::Playlist {
             result["browseId"].cast<std::string>(),
             result["title"].cast<std::string>(),
-            result["author"].cast<std::string>(),
+            result["author"].cast<std::optional<std::string>>(),
             result["itemCount"].cast<std::string>(),
             extract_py_list<meta::Thumbnail>(result["thumbnails"])
         };
@@ -410,36 +419,34 @@ album::Album YTMusic::get_album(const std::string &browseId) const
 std::optional<song::Song> YTMusic::get_song(const std::string &video_id) const
 {
     const auto song = d->get_ytmusic().attr("get_song")(video_id);
+    auto videoDetails = song["videoDetails"].cast<py::dict>();
 
-    if (!song.cast<py::dict>().contains("videoId")) {
+    if (!videoDetails.contains("videoId")) {
         return std::nullopt;
     }
 
     return song::Song {
-        song["videoId"].cast<std::string>(),
-        song["title"].cast<std::string>(),
-        song["lengthSeconds"].cast<std::string>(),
-        extract_py_list<std::string>(song["keywords"]),
-        song["channelId"].cast<std::string>(),
-        song["isOwnerViewing"].cast<bool>(),
-        song["shortDescription"].cast<std::string>(),
-        song["isCrawlable"].cast<bool>(),
+        videoDetails["videoId"].cast<std::string>(),
+        videoDetails["title"].cast<std::string>(),
+        videoDetails["lengthSeconds"].cast<std::string>(),
+        videoDetails["channelId"].cast<std::string>(),
+        videoDetails["isOwnerViewing"].cast<bool>(),
+        videoDetails["isCrawlable"].cast<bool>(),
         song::Song::Thumbnail {
-            extract_py_list<meta::Thumbnail>(song["thumbnail"]["thumbnails"])
+            extract_py_list<meta::Thumbnail>(videoDetails["thumbnail"]["thumbnails"])
         },
-        song["averageRating"].cast<float>(),
-        song["allowRatings"].cast<bool>(),
-        song["viewCount"].cast<std::string>(),
-        song["author"].cast<std::string>(),
-        song["isPrivate"].cast<bool>(),
-        song["isUnpluggedCorpus"].cast<bool>(),
-        song["isLiveContent"].cast<bool>(),
-        song["provider"].cast<std::string>(),
-        extract_py_list<std::string>(song["artists"]),
-        song["copyright"].cast<std::string>(),
-        extract_py_list<std::string>(song["production"]),
-        song["release"].cast<std::string>(),
-        song["category"].cast<std::string>()
+        videoDetails["viewCount"].cast<std::string>(),
+        videoDetails["author"].cast<std::string>(),
+        videoDetails["isPrivate"].cast<bool>(),
+        videoDetails["isUnpluggedCorpus"].cast<bool>(),
+        videoDetails["isLiveContent"].cast<bool>(),
+        [&]() -> std::vector<std::string> {
+            if (videoDetails.contains("artists")) {
+                return extract_py_list<std::string>(videoDetails["artists"]);
+            } else {
+                return {};
+            }
+        }(),
     };
 }
 
@@ -453,7 +460,7 @@ playlist::Playlist YTMusic::get_playlist(const std::string &playlist_id, int lim
         playlist["title"].cast<std::string>(),
         extract_py_list<meta::Thumbnail>(playlist["thumbnails"]),
         extract_meta_artist(playlist["author"]),
-        playlist["year"].cast<std::string>(),
+        optional_key<std::string>(playlist, "year"),
         playlist["duration"].cast<std::string>(),
         playlist["trackCount"].cast<int>(),
         extract_py_list<playlist::Track>(playlist["tracks"]),
